==> mobile_pos-1.0.1.tar.gz: lib/src/views/terminal/transaction_details.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_transaction_icon.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/widget/share_receipt_sheet.dart';
import 'package:mobile_pos/src/views/dispute/log_dispute.dart';

class TransactionDetails extends StatefulWidget {
  final Transaction transaction;
  const TransactionDetails({super.key, required this.transaction});

  @override
  State<TransactionDetails> createState() => _TransactionDetailsState();
}

class _TransactionDetailsState extends State<TransactionDetails> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Row(
                children: [
                  Expanded(
                    child: RavenPayButton(
                      buttonText: "Share Receipt",
                      onPressed: () {
                        showRavenPayBottomSheet(context,
                            child:
                                ShareReceiptSheet(rrn: widget.transaction.rrn));
                      },
                    ),
                  ),
                  const Gap(24),
                  Expanded(
                    child: RavenPayButton(
                      buttonColor: widget.transaction.disputeStatus > 0
                          ? AppColors.ravenOrangeColor
                          : (Colors.transparent),
                      buttonText: "Log Dispute",
                      borderColor: widget.transaction.disputeStatus > 0
                          ? null
                          : pluginConfig.theme!.primaryColor,
                      textColor: widget.transaction.disputeStatus > 0
                          ? Colors.white
                          : pluginConfig.theme!.primaryColor,
                      onPressed: () async {
                        if (widget.transaction.disputeStatus > 0) {
                          showSnack(context,
                              "dispute already logged for this transaction");
                          return;
                        }
                        await pushRoute(
                            context,
                            LogDispute(
                              model: widget.transaction,
                            ));
                        setState(() {});
                      },
                    ),
                  ),
                ],
              ),
              const Gap(30)
            ],
          ),
        ),
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            children: [
              const Gap(24),
              Row(
                children: [
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Gap(4),
                  Text("Transaction Details", style: headling2)
                ],
              ),
              const Gap(24),
              Expanded(
                child: SingleChildScrollView(
                    child: Column(
                  children: [
                    const Gap(34),
                    Stack(
                      clipBehavior: Clip.none,
                      alignment: Alignment.center,
                      children: [
                        Container(
                            padding: const EdgeInsets.symmetric(
                                horizontal: 12, vertical: 12),
                            width: double.infinity,
                            decoration: BoxDecoration(
                                borderRadius: BorderRadius.circular(14),
                                color: pluginTheme.getFGColor),
                            child: Column(
                              children: [
                                const Gap(34),
                                BankBoxMoneyText(
                                  floorAmount: true,
                                  amount: double.tryParse(
                                          widget.transaction.amount) ??
                                      0.0,
                                  fontSize: 18,
                                  fontWeight: FontWeight.w700,
                                  color: headling2.color,
                                ),
                                const Gap(4),
                                Row(
                                  mainAxisAlignment: MainAxisAlignment.center,
                                  children: [
                                    Text(
                                        formateDateGetOnlyDate(
                                            widget.transaction.createdAt),
                                        style: subtitle.copyWith(
                                            fontWeight: FontWeight.w400,
                                            fontSize: 12)),
                                    Container(
                                      margin: const EdgeInsets.symmetric(
                                          horizontal: 8),
                                      height: 4,
                                      width: 4,
                                      decoration: const BoxDecoration(
                                          shape: BoxShape.circle,
                                          color: AppColors.lightTextColor),
                                    ),
                                    Text(
                                        formateDateGetOnlyTime(
                                            widget.transaction.createdAt),
                                        style: subtitle.copyWith(
                                            fontWeight: FontWeight.w400,
                                            fontSize: 12)),
                                  ],
                                ),
                                const Gap(12),
                                Container(
                                    padding: const EdgeInsets.symmetric(
                                        horizontal: 16, vertical: 12),
                                    width: double.infinity,
                                    decoration: BoxDecoration(
                                        borderRadius: BorderRadius.circular(14),
                                        color: pluginTheme.isLightTheme
                                            ? AppColors.lightGrey3
                                            : AppColors.ravenGrey4
                                                .withOpacity(0.04)),
                                    child: Column(
                                      children: [
                                        const Item(
                                          title: "Narration",
                                          value: "Bankbox payment",
                                        ),
                                        Item(
                                          title: "Stan",
                                          value: widget.transaction.stan,
                                        ),
                                        Item(
                                          title: "RRN",
                                          showCopyIcon: true,
                                          value: widget.transaction.rrn,
                                        ),
                                        Item(
                                          title: "Card PAN",
                                          value: widget.transaction.paymentData
                                              .maskedPAN,
                                        ),
                                        Item(
                                          title: "Expiry",
                                          value: widget.transaction.paymentData
                                              .cardExpiry,
                                        ),
                                        Item(
                                          title: "Serial",
                                          value: widget.transaction.serial,
                                        ),
                                        Item(
                                          title: "Amount",
                                          isAmount: true,
                                          value: widget.transaction.amount,
                                          showBorder: false,
                                        ),
                                      ],
                                    ))
                              ],
                            )),
                        Positioned(
                          top: -28,
                          child: BankBoxTransactionIcon(
                            showRoundedBorder: true,
                            size: 56,
                            model: widget.transaction,
                          ),
                        )
                      ],
                    )
                  ],
                )),
              )
            ],
          ),
        ));
  }
}

class Item extends StatelessWidget {
  final String title;
  final String value;
  final bool isAmount;
  final bool showCopyIcon;
  final bool showBorder;
  const Item(
      {super.key,
      required this.title,
      this.isAmount = false,
      required this.value,
      this.showCopyIcon = false,
      this.showBorder = true});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.only(bottom: 18, top: 18),
      decoration: BoxDecoration(
          border: showBorder
              ? Border(
                  bottom: BorderSide(
                      color: pluginTheme.isLightTheme
                          ? AppColors.borderGrey
                          : AppColors.borderGrey.withOpacity(0.08),
                      width: pluginTheme.isLightTheme ? 2 : 0.8))
              : null),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(title, style: subtitle.copyWith(fontWeight: FontWeight.w400)),
          const Gap(12),
          Expanded(
            child: isAmount
                ? BankBoxMoneyText(
                    textAlign: TextAlign.end,
                    floorAmount: true,
                    fontSize: 14,
                    fontWeight: FontWeight.w500,
                    color: AppColors.darkGrey,
                    amount: double.tryParse(value) ?? 0.0)
                : Text(
                    value,
                    style: subtitle.copyWith(
                        color: headling2.color,
                        fontWeight: FontWeight.w500,
                        fontSize: 14),
                    textAlign: TextAlign.end,
                  ),
          ),
          if (showCopyIcon) ...[
            const Gap(2),
            GestureDetector(
              onTap: () {
                copyToClipBoard(context, data: value);
              },
              child: Container(
                  margin: const EdgeInsets.only(top: 4),
                  height: 14,
                  width: 14,
                  child: Image.asset(loadAsset("copy_icon.png"),
                      color: pluginConfig.theme!.primaryColor)),
            )
          ]
        ],
      ),
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/transaction_details.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_transaction_icon.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/widget/share_receipt_sheet.dart';
import 'package:mobile_pos/src/views/dispute/log_dispute.dart';

class TransactionDetails extends StatefulWidget {
  final Transaction transaction;
  const TransactionDetails({super.key, required this.transaction});

  @override
  State<TransactionDetails> createState() => _TransactionDetailsState();
}

class _TransactionDetailsState extends State<TransactionDetails> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        bottomNavigationBar: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Row(
                children: [
                  Expanded(
                    child: RavenPayButton(
                      buttonText: "Share Receipt",
                      onPressed: () {
                        showRavenPayBottomSheet(context,
                            child: ShareReceiptSheet(
                                rrn: widget.transaction.rrn ?? ""));
                      },
                    ),
                  ),
                  const Gap(24),
                  Expanded(
                    child: RavenPayButton(
                      buttonColor: widget.transaction.disputeStatus > 0
                          ? AppColors.ravenOrangeColor
                          : (Colors.transparent),
                      buttonText: "Log Dispute",
                      borderColor: widget.transaction.disputeStatus > 0
                          ? null
                          : pluginConfig.theme!.primaryColor,
                      textColor: widget.transaction.disputeStatus > 0
                          ? Colors.white
                          : pluginConfig.theme!.primaryColor,
                      onPressed: () async {
                        if (widget.transaction.disputeStatus > 0) {
                          showSnack(context,
                              "dispute already logged for this transaction");
                          return;
                        }
                        await pushRoute(
                            context,
                            LogDispute(
                              model: widget.transaction,
                            ));
                        setState(() {});
                      },
                    ),
                  ),
                ],
              ),
              const Gap(30)
            ],
          ),
        ),
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            children: [
              const Gap(24),
              Row(
                children: [
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Gap(4),
                  Text("Transaction Details", style: headling2)
                ],
              ),
              const Gap(24),
              Expanded(
                child: SingleChildScrollView(
                    child: Column(
                  children: [
                    const Gap(34),
                    Stack(
                      clipBehavior: Clip.none,
                      alignment: Alignment.center,
                      children: [
                        Container(
                            padding: const EdgeInsets.symmetric(
                                horizontal: 12, vertical: 12),
                            width: double.infinity,
                            decoration: BoxDecoration(
                                borderRadius: BorderRadius.circular(14),
                                color: pluginTheme.getFGColor),
                            child: Column(
                              children: [
                                const Gap(34),
                                BankBoxMoneyText(
                                  floorAmount: true,
                                  amount: double.tryParse(
                                          widget.transaction.amount ?? "0.0") ??
                                      0.0,
                                  fontSize: 18,
                                  fontWeight: FontWeight.w700,
                                  color: headling2.color,
                                ),
                                const Gap(4),
                                Row(
                                  mainAxisAlignment: MainAxisAlignment.center,
                                  children: [
                                    Text(
                                        formateDateGetOnlyDate(
                                            widget.transaction.createdAt!),
                                        style: subtitle.copyWith(
                                            fontWeight: FontWeight.w400,
                                            fontSize: 12)),
                                    Container(
                                      margin: const EdgeInsets.symmetric(
                                          horizontal: 8),
                                      height: 4,
                                      width: 4,
                                      decoration: const BoxDecoration(
                                          shape: BoxShape.circle,
                                          color: AppColors.lightTextColor),
                                    ),
                                    Text(
                                        formateDateGetOnlyTime(
                                            widget.transaction.createdAt!),
                                        style: subtitle.copyWith(
                                            fontWeight: FontWeight.w400,
                                            fontSize: 12)),
                                  ],
                                ),
                                const Gap(12),
                                Container(
                                    padding: const EdgeInsets.symmetric(
                                        horizontal: 16, vertical: 12),
                                    width: double.infinity,
                                    decoration: BoxDecoration(
                                        borderRadius: BorderRadius.circular(14),
                                        color: pluginTheme.isLightTheme
                                            ? AppColors.lightGrey3
                                            : AppColors.ravenGrey4
                                                .withOpacity(0.04)),
                                    child: Column(
                                      children: [
                                        const Item(
                                          title: "Narration",
                                          value: "Bankbox payment",
                                        ),
                                        Item(
                                          title: "Stan",
                                          value: widget.transaction.stan ?? "",
                                        ),
                                        Item(
                                          title: "RRN",
                                          showCopyIcon: true,
                                          value: widget.transaction.rrn ?? "",
                                        ),
                                        Item(
                                          title: "Card PAN",
                                          value: widget.transaction.paymentData
                                              .maskedPAN,
                                        ),
                                        Item(
                                          title: "Expiry",
                                          value: widget.transaction.paymentData
                                              .cardExpiry,
                                        ),
                                        Item(
                                          title: "Serial",
                                          value:
                                              widget.transaction.serial ?? "",
                                        ),
                                        Item(
                                          title: "Amount",
                                          isAmount: true,
                                          value: widget.transaction.amount ??
                                              "0.0",
                                          showBorder: false,
                                        ),
                                      ],
                                    ))
                              ],
                            )),
                        Positioned(
                          top: -28,
                          child: BankBoxTransactionIcon(
                            showRoundedBorder: true,
                            size: 56,
                            model: widget.transaction,
                          ),
                        )
                      ],
                    )
                  ],
                )),
              )
            ],
          ),
        ));
  }
}

class Item extends StatelessWidget {
  final String title;
  final String value;
  final bool isAmount;
  final bool showCopyIcon;
  final bool showBorder;
  const Item(
      {super.key,
      required this.title,
      this.isAmount = false,
      required this.value,
      this.showCopyIcon = false,
      this.showBorder = true});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.only(bottom: 18, top: 18),
      decoration: BoxDecoration(
          border: showBorder
              ? Border(
                  bottom: BorderSide(
                      color: pluginTheme.isLightTheme
                          ? AppColors.borderGrey
                          : AppColors.borderGrey.withOpacity(0.08),
                      width: pluginTheme.isLightTheme ? 2 : 0.8))
              : null),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(title, style: subtitle.copyWith(fontWeight: FontWeight.w400)),
          const Gap(12),
          Expanded(
            child: isAmount
                ? BankBoxMoneyText(
                    textAlign: TextAlign.end,
                    floorAmount: true,
                    fontSize: 14,
                    fontWeight: FontWeight.w500,
                    color: AppColors.darkGrey,
                    amount: double.tryParse(value) ?? 0.0)
                : Text(
                    value,
                    style: subtitle.copyWith(
                        color: headling2.color,
                        fontWeight: FontWeight.w500,
                        fontSize: 14),
                    textAlign: TextAlign.end,
                  ),
          ),
          if (showCopyIcon) ...[
            const Gap(2),
            GestureDetector(
              onTap: () {
                copyToClipBoard(context, data: value);
              },
              child: Container(
                  margin: const EdgeInsets.only(top: 4),
                  height: 14,
                  width: 14,
                  child: Image.asset(loadAsset("copy_icon.png"),
                      color: pluginConfig.theme!.primaryColor)),
            )
          ]
        ],
      ),
    );
  }
}
